# Function documentation

```{eval-rst}
.. autofunction:: fwdpy11.infinite_sites

    :param rng: Random number generator
    :type rng: :class:`fwdpy11.GSLrng`
    :param pop: A population
    :type pop: :class:`fwdpy11.DiploidPopulation`
    :param mu: The mutation rate, per haploid genome per generation
    :type mu: float

    :return: Number of mutations added
    :rtype: int
```

```{eval-rst}
.. autofunction:: fwdpy11.simplify
```

```{eval-rst}
.. autofunction:: fwdpy11.simplify_tables
```

```{eval-rst}
.. autofunction:: fwdpy11.evolvets
```

```{eval-rst}
.. autofunction:: fwdpy11.data_matrix_from_tables
```

```{eval-rst}
.. autofunction:: fwdpy11.discrete_demography.from_demes
```
